<?php 
return [
  'vendorCredit' => [
    'subject' => 'Vendor Credit Added',
    'content' => 'You have Credit Rs.',
  ],
  'newPayment' => [
    'subject' => 'New Payment Added',
    'text' => 'New Payment has been added for the vendor',
    'action' => 'View Payment',
  ],
  'updatePayment' => [
    'subject' => 'Payment Updated',
    'text' => 'Payment has been updated for the vendor',
    'action' => 'View Payment',
  ],
  'vendorPayment' => [
    'subject' => 'New Payment has been received',
    'text' => 'You have received new payment from ',
    'text2' => 'of amount',
    'action' => 'View Payment',
    'thankyouNote' => 'Thank you for your business',
  ],
  'purchaseBill' => [
    'NewBill' => [
      'subject' => 'New Bill Received',
      'text' => 'You have received new bill from',
      'text2' => 'of amount',
      'action' => 'View Bill',
    ],
  ],
  'purchaseOrder' => [
    'subject' => 'New Order Received',
    'text' => 'A New Order has been received of amount',
    'action' => 'View Order',
    'updateSubject' => 'Order Updated',
    'updateText' => 'Order has been updated.',
    'updateTextSms' => 'Order has been updated.',
  ],
  'purchaseInventory' => [
    'text' => 'New stock has been adjusted in Inventory.',
    'viewInventory' => 'View Inventory',
    'subject' => 'Inventory adjusted',
  ],
];