<?php 
return [
  'product' => [
    'type' => 'Type',
    'goods' => 'Goederen',
    'images' => 'Afbeeldingen',
    'service' => 'Dienst',
    'addImages' => 'Afbeeldingen toevoegen',
    'toBeBilled' => 'Te factureren',
    'productInfo' => 'Product informatie',
    'productType' => 'product type',
    'stockOnHand' => 'Voorraad bij de hand',
    'transactions' => 'Transacties',
    'openingStock' => 'Openingsvoorraad',
    'toBeInvoiced' => 'Gefactureerd worden',
    'committedStock' => 'Toegewijde voorraad',
    'newTransaction' => 'Nieuwe transactie',
    'availableForSale' => 'Beschikbaar voor verkoop',
    'modeOfAdjustment' => 'Wijze van aanpassing',
    'referenceNumber' => 'Referentienummer',
    'quantityAdjustment' => 'Aanpassing van de hoeveelheid',
    'valueAdjustment' => 'Waardeaanpassing',
    'reason' => 'Reden',
    'availableQuantity' => 'Beschikbare kwaliteit',
    'quantityOnHand' => 'Hoeveelheid op voorraad',
    'quabtityAdjusted' => 'Aantal aangepast',
    'costPrice' => 'Kostprijs',
    'currentValue' => 'Huidige waarde',
    'changedValue' => 'Gewijzigde waarde',
    'adjustedValue' => 'Aangepaste waarde',
    'Created' => 'Nieuw product gemaakt',
    'productCreated' => 'Product gemaakt door',
    'productUpdated' => 'Product bijgewerkt door',
    'Updated' => 'Product bijgewerkt',
    'newQuantityOnHand' => 'Nieuwe hoeveelheid bij de hand',
  ],
  'inventory' => [
    'adjustmentReason' => 'Reden voorraadaanpassing',
    'reasonName' => 'Naam van de reden',
    'addReason' => 'Reden toevoegen',
    'adjustedby' => 'Aangepast door',
    'inventoryInfo' => 'Voorraadinformatie',
    'files' => 'Bestanden',
    'addFiles' => 'Bestanden toevoegen',
    'Created' => 'Voorraad aangemaakt',
    'inventoryCreated' => 'Er wordt voorraad van het product aangemaakt',
    'fileCreated' => 'Voorraadbestand geüpload',
    'inventoryFileCreated' => 'Er wordt een inventarisbestand geüpload door',
    'active' => 'Actief',
    'inactive' => 'Inactief',
    'inventoryStatus' => 'Voorraadstatus',
    'inventoryAssetValue' => 'Voorraadwaarde van activa',
    'inventoryNumber' => 'INVENTARIS NUMMER',
    'inventoryDate' => 'INVENTARIS DATUM',
    'companyDetail' => 'Bedrijfsgegevens',
    'inventoryDateInSmall' => 'Inventarisdatum',
    'withQuantityOnHand' => 'met hoeveelheid bij de hand',
    'fromValue' => 'van Waarde',
    'toNewValue' => 'naar nieuwe Waarde',
    'details' => 'Voorraad wordt aangemaakt door',
  ],
  'vendor' => [
    'primaryContactName' => 'Naam primaire contactpersoon',
    'companyName' => 'Bedrijfsnaam',
    'otherDetails' => 'Andere details',
    'openingsBalance' => 'Openingssaldo',
    'accountDetails' => 'Accountgegevens',
    'billDetails' => 'Factuurgegevens',
    'vendorCreditNumber' => 'Kredietnummer van de leverancier',
    'vendorCrediTDate' => 'Creditdatum leverancier',
    'prefix' => 'Kredietnr',
    'vendorName' => 'Naam van de leverancier',
    'creditDate' => 'Creditdatum',
    'amount' => 'Hoeveelheid',
    'paymentToVendor' => 'Betaling aan verkoper',
    'outstandingPayable' => 'Openstaande schulden',
    'unusedCredit' => 'Ongebruikte tegoeden',
    'overView' => 'Overzicht',
    'notes' => 'Opmerkingen',
    'contacts' => 'Contacten',
    'history' => 'Geschiedenis',
    'vendorCreated' => 'Leverancier is gemaakt door',
    'vendorUpdated' => 'Leverancier is bijgewerkt door',
    'noteTitle' => 'Opmerking Titel',
    'noteType' => 'Notitietype',
    'vendorNoteCreated' => 'Opmerking is gemaakt door',
    'vendorNoteUpdated' => 'Leveranciersnota is bijgewerkt door',
    'vendorContactCreated' => 'Contact aangemaakt door',
    'vendorContactUpdated' => 'Leverancierscontact bijgewerkt door',
    'vendorAdded' => 'Leverancier toegevoegd',
    'contactUpdated' => 'Leverancierscontact bijgewerkt',
    'contactCreated' => 'Leverancierscontact aangemaakt',
    'noteCreated' => 'Leveranciersnotitie gemaakt',
    'noteUpdated' => 'Leveranciersnotitie bijgewerkt',
    'Created' => 'Leverancier gemaakt',
    'Updated' => 'Leverancier bijgewerkt',
    'vendors' => 'Verkoper',
    'billedAmount' => 'Gefactureerd bedrag',
    'closingBalance' => 'Eindsaldo',
    'purchaseOrders' => 'Inkooporders',
    'payments' => 'Betalingen',
  ],
  'vendorPayment' => [
    'addPayment' => 'Betaling toevoegen',
    'billAmount' => 'Rekening hoeveelheid',
    'amountDue' => 'Te betalen bedrag',
    'amountUsed' => 'Bedrag gebruikt voor betalingen',
    'amountRefunded' => 'Bedrag terugbetaald',
    'amountInExcess' => 'Bedrag in overmaat',
    'vendorPaymentDetails' => 'Betalingsgegevens van leverancier',
    'overView' => 'Overzicht',
    'notes' => 'Opmerkingen',
    'contacts' => 'Contacten',
    'payInFull' => 'Betaal alles',
    'paymentMade' => 'Betaling gedaan',
    'paymentDate' => 'Betaaldatum',
    'noBills' => 'Er zijn geen facturen voor de geselecteerde leverancier',
    'excessPaymentMsg' => 'U staat op het punt een teveelbetaling van te boeken',
    'excessMsg' => '. Dit wordt opgeslagen als tegoed voor de leverancier. Wil je doorgaan?',
    'continueToSave' => 'Ga door met opslaan',
    'internalNote' => 'Interne opmerking',
    'internalUse' => 'Intern gebruik, niet zichtbaar voor leverancier',
    'shouldBeGreater' => 'Het overtollige bedrag kan niet negatief zijn',
    'purchaseOrderNumber' => 'Aankoop order nummer',
    'billDate' => 'Factuurdatum',
    'paymentToVendor' => 'Betaling aan verkoper',
    'outstandingPayable' => 'Openstaande schulden',
    'unusedCredit' => 'Ongebruikte tegoeden',
    'history' => 'Geschiedenis',
    'vendorCreated' => 'Leverancier is gemaakt door',
    'vendorUpdated' => 'Leverancier is bijgewerkt door',
    'noteTitle' => 'Opmerking Titel',
    'noteType' => 'Notitietype',
    'vendorNoteCreated' => 'Opmerking is gemaakt door',
    'vendorNoteUpdated' => 'Leveranciersnota is bijgewerkt door',
    'vendorContactCreated' => 'Contact aangemaakt door',
    'vendorContactUpdated' => 'Leverancierscontact bijgewerkt door',
    'vendorAdded' => 'Leverancier toegevoegd',
    'contactUpdated' => 'Leverancierscontact bijgewerkt',
    'contactCreated' => 'Leverancierscontact aangemaakt',
    'noteCreated' => 'Leveranciersnotitie gemaakt',
    'noteUpdated' => 'Leveranciersnotitie bijgewerkt',
    'Created' => 'Leveranciersbetaling aangemaakt',
    'Updated' => 'Leveranciersbetaling bijgewerkt',
    'vendors' => 'Verkoper',
    'vendorPaymentCreated' => 'Er wordt een betaling gemaakt van het bedrag',
    'vendorPaymentUpdated' => 'Een betaling is bijgewerkt van het bedrag',
    'ofPurchaseOrder' => 'van het inkoopordernummer',
    'by' => 'door',
    'sendNotification' => 'Stuur een e-mailmelding naar de leverancier',
    'clearAppliedAmount' => 'Wis toegepast bedrag',
  ],
  'purchaseSettings' => [
    'purchaseOrderPrefix' => 'Voorvoegsel inkooporder',
    'purchaseOrderNumberSeprator' => 'Scheidingsteken voor inkoopordernummers',
    'purchaseOrderDigits' => 'Cijfers inkoopordernummer',
    'purchaseOrderExample' => 'Voorbeeld van inkoopordernummer',
    'billOrderPrefix' => 'Voorvoegsel factuurorder',
    'billOrderNumberSeprator' => 'Scheidingsteken voor factuurordernummer',
    'venodrCreditPrefix' => 'Leverancierskredietvoorvoegsel',
    'venodrCreditNumberSeprator' => 'Scheidingsteken voor leverancierskredietnummers',
    'vendorCreditDigits' => 'Cijfers van het kredietnummer van de leverancier',
    'vendorCreditExample' => 'Voorbeeld van leverancierskredietnummer',
    'termsAndCondition' => 'Algemene voorwaarden',
    'billOrderDigits' => 'Factuurordercijfers',
    'billOrderExample' => 'Voorbeeld factuurorder',
  ],
  'vendorCredit' => [
    'vendorCreditCreated' => 'Leverancierskrediet wordt aangemaakt door',
    'vendorCreditUpdated' => 'Leverancierskrediet wordt bijgewerkt door',
    'Created' => 'Leverancierskrediet aangemaakt',
    'Updated' => 'Leverancierskrediet bijgewerkt',
    'ofAmount' => 'van bedrag',
  ],
  'purchaseBill' => [
    'saveAsOpen' => 'Opslaan als geopend',
    'billCreated' => 'Er wordt een factuur gemaakt van het bedrag',
    'billUpdated' => 'Factuurdatum is bijgewerkt naar',
    'Created' => 'Factuur gemaakt',
    'Updated' => 'Factuur bijgewerkt',
    'by' => 'door',
    'ofPurchaseOrder' => 'van de inkooporder',
    'partially_paid' => 'Gedeeltelijk betaald',
    'onDate' => 'op datum',
  ],
  'purchaseOrder' => [
    'expectedDate' => 'Verwachte datum',
    'billedStatus' => 'Gefactureerde status',
    'billed' => 'Gefactureerd',
    'unbilled' => 'Niet gefactureerd',
    'open' => 'Open',
    'draft' => 'Voorlopige versie',
    'purchaseOrderCreated' => 'Inkooporder is aangemaakt door',
    'purchaseOrderUpdated' => 'Inkooporder is bijgewerkt door',
    'Created' => 'Inkooporder aangemaakt',
    'Updated' => 'Inkooporder bijgewerkt',
    'convertToBill' => 'Converteren naar factuur',
    'count' => 'Graaf',
    'deliveryStatus' => 'Aflever status',
    'notStarted' => 'Niet begonnen',
    'inTransaction' => 'In transactie',
    'deliveryFailed' => 'Bezorging mislukt',
    'delivered' => 'Afgeleverd',
    'expectedDeliveryDate' => 'Verwachte leverdatum',
    'orderDate' => 'Besteldatum',
  ],
  'reports' => [
    'inventorySummary' => 'Inventarisoverzicht',
    'itemName' => 'Itemnaam',
    'sku' => 'SKU',
    'quantityOrdered' => 'Hoeveelheid besteld',
    'quantityIn' => 'Hoeveelheid in',
    'quantityOut' => 'Hoeveelheid uit',
    'stockOnHand' => 'Voorraad bij de hand',
    'committedStock' => 'Toegewijde voorraad',
    'availableForSale' => 'Beschikbaar voor verkoop',
  ],
];