<?php 
return [
  'trackInventoryMsg' => 'U kunt het bijhouden van de voorraad niet meer in- of uitschakelen nadat u transacties voor dit artikel heeft gemaakt.',
  'openingStockRequired' => 'Openingsvoorraad vereist als u voorraad bijhouden hebt ingeschakeld.',
  'ratePerUnitRequired' => 'Tarief per eenheid vereist als u voorraad bijhouden heeft ingeschakeld.',
  'sellingPriceRequired' => 'Verkoopprijs vereist als u verkoopinformatie heeft ingeschakeld.',
  'purchasePriceRequired' => 'Aankoopprijs vereist als u aankoopinformatie heeft ingeschakeld.',
  'confirmInactive' => 'Ja, inActiveer het!',
  'productStatusChanged' => 'Productstatus is succesvol gewijzigd.',
  'purchaseOrderPaymentBlank' => 'Betaling van de inkooporder mag niet blanco zijn.',
  'paymentConfirmation' => 'Kredietsaldo bijgewerkt',
  'messagePayment' => 'Betaald bedrag:',
  'remainingCreditAmount' => 'Resterend kredietbedrag:',
  'thankYou' => 'Bedankt voor uw bedrijf!',
  'inventory' => [
    'itemBlank' => 'Voorhanden aantal kan niet leeg zijn.',
    'unitPriceNumber' => 'De gewijzigde waarde moet een getal zijn',
    'itemValueBlank' => 'De gewijzigde waarde mag niet leeg zijn.',
    'reason' => 'Selecteer de reden.',
    'type' => 'Er is een aanpassingsmodus vereist.',
    'quantityCannotLessThan' => 'Het aantal kan niet kleiner zijn dan het gefactureerde aantal',
  ],
  'confirmStatus' => 'Ja, status wijzigen!',
  'confirmActiveStatus' => 'Het zal ook de status wijzigen, aangepast voor elk product op voorraad!',
  'confirmInactiveStatus' => 'Het zal ook de status wijzigen die voor elk product op voorraad wordt opgesteld!',
  'orderMarkAsSent' => 'Bestelling succesvol verzonden',
  'orderSentSuccessfully' => 'Bestelling Markeren als succesvol verzonden',
  'billSentSuccessfully' => 'Factuur succesvol verzonden.',
];