<?php 
return [
  'qty' => 'Aantal',
  'val' => 'Val',
  'sku' => 'SKU',
  'sellingPrice' => 'Verkoopprijs',
  'costPrice' => 'Kostprijs',
  'ratePerUnit' => 'Tarief per eenheid',
  'openingStock' => 'Openingsvoorraad',
  'markAsInactive' => 'Markeer als inactief',
  'salesInformation' => 'Verkoopinformatie',
  'trackInventory' => 'Houd de voorraad voor dit artikel bij',
  'purchaseInformation' => 'aankoop informatie',
  'addVendorNote' => 'Leveranciersnotitie toevoegen',
  'vendor' => 'Leverancier',
  'adjustStock' => 'Voorraad aanpassen',
  'editVendorNote' => 'Leveranciersnotitie bewerken',
  'addReason' => 'Voeg reden toe',
  'addInventory' => 'Voeg voorraad toe',
  'inventoryDetails' => 'Inventarisgegevens',
  'markActive' => 'Markeer als actief',
  'markInactive' => 'Markeer als inactief',
  'itemName' => 'Itemnaam',
  'selectVendor' => 'Selecteer Leverancier',
  'applyToBill' => 'Betaal de factuur met leverancierskrediet',
  'deliveryAddresses' => 'Bezorgadres',
  'availableStock' => 'Beschikbare voorraad',
  'availableBalance' => 'beschikbaar saldo',
  'defaultImage' => 'Standaardafbeelding',
  'menu' => [
    'purchase' => 'Aankoop',
    'purchaseSettings' => 'Aankoopinstellingen',
    'purchaseNotificationSettings' => 'Instellingen voor aankoopmeldingen',
    'new-purchase-bill' => 'Nieuwe aankoopfactuur',
    'new-purchase-inventory' => 'Nieuwe inkoopinventaris',
    'new-purchase-order' => 'Nieuwe inkooporder',
    'vendor-credit' => 'Leverancierskrediet',
    'admin-new-vendor-payment' => 'Beheerder Betaling nieuwe leverancier',
    'update-new-vendor-payment' => 'Update nieuwe leveranciersbetaling',
    'vendor' => 'Leverancier',
    'products' => 'Producten',
    'addVendor' => 'Leverancier toevoegen',
    'editVendor' => 'Leverancier bewerken',
    'purchaseCode' => 'Aankoopcode',
    'prefixSettings' => 'Voorvoegselinstellingen',
    'vendorReport' => 'Leveranciersrapport',
    'orderReport' => 'Inkooporderrapport',
    'inventory' => 'Inventaris',
    'bill' => 'Rekening',
    'bills' => 'Rekeningen',
    'billDate' => 'Factuurdatum',
    'billNumber' => 'Rekeningnummer',
    'purchaseOrder' => 'Bestelling',
    'receipt' => 'Ontvangst',
    'report' => 'Rapport',
    'paymentDate' => 'Betaaldatum',
    'paymentMade' => 'Betaling gedaan',
    'internalNote' => 'Interne opmerking',
    'billItems' => 'Factuurartikelen',
    'createBill' => 'Maak een factuur',
    'reports' => 'Rapporten',
    'addFiles' => 'Bestanden toevoegen',
    'inventoryValuationSummary' => 'Samenvatting inventariswaardering',
    'addPayment' => 'Betaling toevoegen',
    'vendorCredits' => 'Leverancierskredieten',
    'vendorCredit' => 'Leverancierskrediet',
    'addVendorCredit' => 'Leverancierskrediet toevoegen',
    'addCredit' => 'Voeg krediet toe',
    'billAmount' => 'Rekening hoeveelheid',
    'billDue' => 'Factuur verschuldigd',
    'creditNumber' => 'Kredietnummer',
    'paymentReceipt' => 'Betalingsbewijs',
    'vendorName' => 'Naam van de leverancier',
    'bankAccount' => 'Bankrekening',
  ],
  'purchaseOrder' => [
    'vendorPayments' => 'Leveranciersbetalingen',
    'addVendorPayments' => 'Leveranciersbetaling toevoegen',
    'purchaseOrder' => 'Bestelling',
    'vendorName' => 'Naam van de leverancier',
    'paymentToVendor' => 'Betaling aan verkoper',
  ],
];